@@ -18,6 +18,19 @@
 from __future__ import unicode_literals
 
 
+class UserDestination(object):
+    def __init__(self, user_id):
+        self.user_id = user_id
+
+    def to_obj_dict(self):
+        obj_dict = {
+            'actiontype': 'group',
+            'actionarg1': self.user_id,
+            'actionarg2': '',
+        }
+        return obj_dict
+
+
 class GroupDestination(object):
     def __init__(self, group_id):
         self.group_id = group_id
